@@ -146,12 +146,12 @@ class ZPBankAction:
                         transAction = Transaction(
                             user=trans.user,
                             amount=trans.amount,
-                            type='1',
+                            type='+',
                             subject=_("Charge"),
                             bank_transaction=trans,
                         )
                         transAction.save()
-                        trans.user.amount += trans.amount
+                        trans.user.success_transaction(trans, req.json())
                         trans.card_hash = req.json()['data']['card_pan']
                         trans.ref_id = req.json()['data']['ref_id']
                         trans.user.save()
@@ -170,7 +170,7 @@ class ZPBankAction:
                     trans.save()
                     return render(request, 'transaction/transaction_result.html', {
                         'state': False,
-                        'error': req.json()['errors']['message']})
+                        'error': req.json()['errors']['message'] if req.json()['errors'] else []})
                 else:
                     return render(request, 'transaction/transaction_result.html', {
                         'state': False,
